@@ -20,11 +20,11 @@ Pod::Query - Query pod documents
 
 =head1 VERSION
 
-Version 0.13
+Version 0.14
 
 =cut
 
-our $VERSION                   = '0.13';
+our $VERSION                   = '0.14';
 our $DEBUG_LOL_DUMP            = 0;
 our $DEBUG_STRUCT_OVER         = 0;
 our $DEBUG_TREE                = 0;
@@ -38,10 +38,10 @@ our $DEBUG_INVERT              = 0;
 our $DEBUG_RENDER              = 0;
 our $MOCK_ROOT                 = 0;
 
-
 has [
     qw/
-      path lol
+      path
+      lol
       tree
       title
       events
@@ -379,8 +379,9 @@ Extracts the complete method information.
 
 sub find_method {
     my ( $s, $method ) = @_;
-    $s->find( sprintf '~head=~^%s\b.*$[0]**',
-        $s->_clean_method_name( $method ) );
+    my $m = $s->_clean_method_name( $method ) or return "";
+
+    $s->find( sprintf '~head=~^%s\b.*$[0]**', $m );
 }
 
 
@@ -392,10 +393,10 @@ Extracts the method summary.
 
 sub find_method_summary {
     my ( $s, $method ) = @_;
-    scalar $s->find( sprintf '~head=~^%s\b.*$[0]/~(Data|Para)[0]',
-        $s->_clean_method_name( $method ) );
-}
+    my $m = $s->_clean_method_name( $method ) or return "";
 
+    scalar $s->find( sprintf '~head=~^%s\b.*$[0]/~(Data|Para)[0]', $m );
+}
 
 =head2 _clean_method_name
 
@@ -405,7 +406,15 @@ Returns a method name without any possible parenthesis.
 
 sub _clean_method_name {
     my ( $s, $name ) = @_;
-    $name =~ s/[^a-zA-Z0-9_]+//gr;
+    my $safe_start = qr/ ^ [\w_] /x;
+    my $safe_end   = qr/ [\w_()] $ /x;
+    return if $name !~ $safe_start;
+    return if $name !~ $safe_end;
+
+    my $clean = quotemeta( $name =~ s/[^a-zA-Z0-9_]+//gr );
+    return if $clean !~ $safe_start;
+
+    $clean;
 }
 
 
@@ -498,7 +507,7 @@ sub find {
     }
     if ( $DEBUG_FIND_DUMP ) {
         say "DEBUG_FIND_DUMP: " . dumper \@tree;
-        exit;
+        exit if $DEBUG_FIND_DUMP > 1;
     }
 
     if ( not $kept_all ) {
@@ -531,8 +540,9 @@ Convert a pod query string into a structure based on these rules:
    5. Split each list of conditions by "=".
       First word is the tag.
       Second word is the text (if any).
-      If either starts with a tilde, then the word
-         is treated like a pattern.
+      If either starts with a tilde, then the word:
+         - is treated like a pattern.
+         - is case Insensitive.
 
    Precedence:
       If quoted and ~, left wins:
@@ -587,7 +597,7 @@ sub _query_string_to_struct {
         for ( qw/ tag text / ) {
             last if not @condition;
             my $cond = shift @condition;
-            $set->{$_} = ( $cond =~ s/^~// ) ? qr/$cond/ : $cond;
+            $set->{$_} = ( $cond =~ s/^~// ) ? qr/$cond/i : $cond;
         }
 
         $set;
